@@ -105,6 +105,13 @@ sol_set_t *solve(problem_t *problem, solve_params_t *params)
         return data.sol;
     }
 
+    if (params->newton && problem->numvars != problem->numeqns) {
+        fprintf(stderr, "Error: Can't use Newton's method when the number of ");
+        fprintf(stderr, "variables is not equal to\n");
+        fprintf(stderr, "       the number of equations.\n");
+        return data.sol;
+    }
+
     data.problem = problem;
     data.params = params;
     data.iter = 0;
@@ -202,10 +209,9 @@ void solve_once(problem_t *problem, sol_set_t *sol, pthread_mutex_t *mutex,
     i = 0;
     for (;;) {
         int     num_solns;
-        double  diff;
+        double  diff = 0.0;
 
         for (j = 0; j < COMPARE_FREQ; i++, j++) {
-
             memcpy(old_x, x, problem->numvars * sizeof(double));
             em_step(problem, x, ipf_thresh);
             diff = diff_solns(old_x, x, problem->numvars);
